#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://libinklevel.sourceforge.net/
# source           : http://prdownloads.sourceforge.net/libinklevel/libinklevel-0.8.0rc1.tar.gz
# Maintainer       : Patrick Smith BandiPat <magicpage91@earthlink.net>

# Package name
NAME="libinklevel"
# Package version
VERSION="0.8.0rc1"
# Source code URL
SOURCE="http://prdownloads.sourceforge.net/libinklevel/libinklevel-$VERSION.tar.gz?download"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS  CHANGELOG  COPYING  README"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 make-jobs at once
#
#numjobs='-j6'
#
# I only have a 'light' computer: 2 make-jobs at once
#
numjobs='-j2'

#
#---------------------------------------------------------------------
# Note: for a rebuild you should normally not have to change anything
# below this comment
#---------------------------------------------------------------------
#

#
# a lonesome 'hook': the other end is at the bottom of the buildfile
# the combination gives me a full log of the build-process in the
# file: "$softname-$softversion-info.txt"
#
(

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="60.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: libinklevel - Check the ink level of your printer with linux
$NAME:
$NAME: libinklevel is a library for checking the ink level of your printer
$NAME: on a system which runs Linux. It supports printers attached via
$NAME: parallel port or usb.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# Configure and make
cd $NAME-$VERSION
sed -i -e 's,PREFIX = /usr/local,PREFIX = /usr,' Makefile
sed -i -e 's/CFLAGS = -Wall -O2 -fPIC -DPIC -I./CFLAGS = -Wall -O2 -march=i486 -mtune=i686 -fPIC -DPIC -I./' Makefile
make

# Install on temporary directory
mkdir -p $PKG/usr
make install DESTDIR=$PKG

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
echo "--- generating the md5sum -----"
(
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

echo "--- packaging extra files-----"
echo "--- generating the package dependencies -----"
depfinder -f $NAME-$VERSION-$ARCH-$BUILD.tgz >$NAME-$VERSION-$ARCH-$BUILD.dep
echo "---generating the .src file & build text---"

#
# produce the file src
#
echo http://zenwalk.pinguix.com/user-accounts/BandiPat/source/build-files/build-libinklevel.sh > $NAME-$VERSION-$ARCH-$BUILD.src
echo $SOURCE >> $NAME-$VERSION-$ARCH-$BUILD.src
)

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG

#
# the other end of the lonesome hook: 
#
) 2>&1 | tee "$NAME-$VERSION-build.txt"
